@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: matcher.c,v 1.7 2006/02/03 13:27:26 behdad Exp $"
 
 #include "../config.h"
 #include <sys/types.h>
@@ -60,7 +59,7 @@ _vte_matcher_add(struct _vte_matcher *matcher,
 
 /* Loads all sequences into matcher */
 static void
-_vte_matcher_init(struct _vte_matcher *matcher, char *emulation,
+_vte_matcher_init(struct _vte_matcher *matcher, const char *emulation,
 		  struct _vte_termcap *termcap)
 {
 	const char *code, *value;
@@ -79,7 +78,7 @@ _vte_matcher_init(struct _vte_matcher *matcher, char *emulation,
 	/* Load the known capability strings from the termcap structure into
 	 * the table for recognition. */
 	for (i = 0;
-	     _vte_terminal_capability_strings[i].capability != NULL;
+	     _vte_terminal_capability_strings[i].capability[0];
 	     i++) {
 		if (_vte_terminal_capability_strings[i].key) {
 			continue;
@@ -148,7 +147,7 @@ _vte_matcher_create(gpointer key)
 		fprintf(stderr, "_vte_matcher_create()\n");
 	}
 #endif
-	ret = g_malloc(sizeof(struct _vte_matcher));
+	ret = g_slice_new(struct _vte_matcher);
 	ret->initialized = FALSE;
 	ret->type = _vte_matcher_trie;
 	ret->table = NULL;
@@ -190,12 +189,12 @@ _vte_matcher_destroy(gpointer value)
 	if (matcher->trie != NULL) {
 		_vte_trie_free(matcher->trie);
 	}
-	g_free(matcher);
+	g_slice_free(struct _vte_matcher, matcher);
 }
 
 /* Create and init matcher. */
 struct _vte_matcher *
-_vte_matcher_new(char *emulation, struct _vte_termcap *termcap)
+_vte_matcher_new(const char *emulation, struct _vte_termcap *termcap)
 {
 	struct _vte_matcher *ret = NULL;
 	g_static_mutex_lock(&_vte_matcher_mutex);
@@ -206,11 +205,12 @@ _vte_matcher_new(char *emulation, struct _vte_termcap *termcap)
 
 	if (_vte_matcher_cache == NULL) {
 		_vte_matcher_cache = g_cache_new(_vte_matcher_create,
-				_vte_matcher_destroy, g_strdup, g_free,
+				_vte_matcher_destroy,
+			       	(GCacheDupFunc) g_strdup, g_free,
 				g_str_hash, g_direct_hash, g_str_equal);
 	}
 
-	ret = g_cache_insert(_vte_matcher_cache, emulation);
+	ret = g_cache_insert(_vte_matcher_cache, (gpointer) emulation);
 
 	if (!ret->initialized) {
 		_vte_matcher_init(ret, emulation, termcap);
